@@ -1,31 +1,22 @@
-/*******************************************************************************
- * Licensed Materials - Property of IBM
- * (c) Copyright IBM Corporation 2019. All Rights Reserved.
- *
- * Note to U.S. Government Users Restricted Rights:
- * Use, duplication or disclosure restricted by GSA ADP Schedule
- * Contract with IBM Corp.
- *******************************************************************************/
-/* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright (c) 2021 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 'use strict'
 
 import React from 'react'
 import PropTypes from 'prop-types'
 import { connect } from 'react-redux'
 import { withRouter } from 'react-router-dom'
-import resources from '../../../lib/shared/resources'
 import { updateActiveFilters } from '../../actions/common'
-import { Icon, Tag } from 'carbon-components-react'
-import msgs from '../../../nls/platform.properties'
+import { Chip } from '@patternfly/react-core'
+import msgs from '../../nls/platform.properties'
 import _ from 'lodash'
 import queryString from 'query-string'
-import { saveSessionState } from '../../components/common/AccessStorage'
-import { GRC_FILTER_STATE_COOKIE } from '../../../lib/shared/constants'
+import { saveSessionState } from '../../utils/AccessStorage'
+import { GRC_FILTER_STATE_COOKIE } from '../../utils/constants'
 import TruncateText from '../../components/common/TruncateText'
 
-resources(() => {
-  require('../../../scss/resource-filterbar.scss')
-})
+import '../../scss/resource-filterbar.scss'
 
 class ResourceFilterBar extends React.Component {
   constructor (props) {
@@ -55,27 +46,37 @@ class ResourceFilterBar extends React.Component {
     })
     if (clearFilters.length>0) {
       // clear all tag
-      const clearAll = msgs.get('filter.remove.all', locale)
+      // const clearAll = msgs.get('filter.remove.all', locale)
       return (
         <div className='resource-filter-bar'>
           <span className='title'>{msgs.get('filter.remove.filters', locale)}</span>
-          {boundFilters.map(({name, onClick, onKeyPress}) => {
-            return <Tag key={name} type='custom' tabIndex={0} role={'button'} onKeyPress={onKeyPress}>
-              <TruncateText maxCharacters={20} text={name} />
-              <Icon
-                className='closeIcon'
-                description={msgs.get('filter.remove.tag', locale)}
-                name="icon--close"
-                onClick={onClick}
-              />
-            </Tag>
+          {boundFilters.map(({name, onClick}) => {
+            return (
+              <Chip key={name} onClick={onClick} >
+                <TruncateText maxCharacters={20} text={name} />
+              </Chip>
+            )
+            // return <ChipGroup
+            //         key={name}
+            //         type='custom'
+            //         role={'button'}
+            //         onKeyPress={onKeyPress}
+            //         >
+            //           <TruncateText maxCharacters={20} text={name} />
+            //           <Chip
+            //             key={_uniqueId('tag')}
+            //             className='closeIcon'
+            //             description={msgs.get('filter.remove.tag', locale)}
+            //             onClick={onClick}
+            //           />
+            //         </ChipGroup>
           })}
-          <span className='button' tabIndex={0} role={'button'}
+          {/* <span className='button' tabIndex={0} role={'button'}
             title={clearAll} aria-label={clearAll}
             onClick={this.handleClearClick.bind(this)}
             onKeyPress={this.handleClearKeyPress.bind(this)} >
             {clearAll}
-          </span>
+          </span> */}
         </div>
       )
     }
